intelmq.bots.parsers.malwaredomains package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.parsers.malwaredomains package

## Submodules

## intelmq.bots.parsers.malwaredomains.parser module

The descriptions give a hint about what the entry is about and is very mixed. Most prominent description is “phishing”, most of them are malware names. More types could be mapped better, only the most obvious ones are done currently.

`intelmq.bots.parsers.malwaredomains.parser.` `BOT`

  alias of `intelmq.bots.parsers.malwaredomains.parser.MalwareDomainsParserBot`

class `intelmq.bots.parsers.malwaredomains.parser.` `MalwareDomainsParserBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  Parse the Malware Domains feed

  `is_valid_date`(strd)
  `process`()

## Module contents